<?php
/*
Plugin Name: Simple Image Source Control
Plugin URI: https://europa-host.de
Description: Fügt ein Feld für die Bildquelle in der Medienbibliothek hinzu und zeigt die Bildquellen unter den Beiträgen an. Importiert vorhandene Bildquellen von ISC.
Version: 2.31
Author: Peter Wilhelm
Author URI: https://europa-host.de
*/


// Hinzufügen und Speichern der Bildquelle
function sisc_add_image_source_field($form_fields, $post) {
    $field_value = get_post_meta($post->ID, 'sisc_image_source', true);
    $form_fields['sisc-image-source'] = array(
        'label' => 'Bildquelle',
        'input' => 'text',
        'value' => $field_value,
        'helps' => 'Geben Sie den Urheber des Bildes ein'
    );
    return $form_fields;
}
add_filter('attachment_fields_to_edit', 'sisc_add_image_source_field', 10, 2);

function sisc_save_image_source_field($post, $attachment) {
    if (isset($attachment['sisc-image-source'])) {
        update_post_meta($post['ID'], 'sisc_image_source', $attachment['sisc-image-source']);
    }
    return $post;
}
add_filter('attachment_fields_to_save', 'sisc_save_image_source_field', 10, 2);

// Anzeigen der Bildquellen und Bildnamen unter Beiträgen
function sisc_display_image_sources($content) {
    global $post;
    $attachments = get_posts(array(
        'post_type' => 'attachment',
        'posts_per_page' => -1,
        'post_parent' => $post->ID
    ));

    if ($attachments) {
        $content .= '<div class="image-sources"><strong>Bildquellen:</strong><ul>';
        foreach ($attachments as $attachment) {
            $isc_source = get_post_meta($attachment->ID, 'isc_image_source', true);
            $sisc_source = get_post_meta($attachment->ID, 'sisc_image_source', true);
            $source = !empty($isc_source) ? $isc_source : $sisc_source;
            $filename = basename(get_attached_file($attachment->ID));
            if (!empty($source)) {
                $content .= '<li>' . esc_html($filename) . ': ' . esc_html($source) . '</li>';
            }
        }
        $content .= '</ul></div>';
    }
    return $content;
}
add_filter('the_content', 'sisc_display_image_sources');
